package com.academiaandroid.carteraclientes;

//Aplicacin Android que implementa una base de datos SQLite,
//para posteriormente definir un Content Provider para la creacin, consulta, actualizacin y borrado
//de registros.
//
//academiaandroid.com
//
//by Jos Antonio Gzquez Rodrguez

import android.content.Context;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

/*Clase BaseDatos, que hereda de la clase base SQLiteOpenHelper, encargada de 
sobrescribir los mtodos para la creacin, actualizacin y consultas a una Base de Datos.*/
public class BaseDatos extends SQLiteOpenHelper{

	/*Se declara e inicializa una variable encargada de controlar el tipo de dato
	de cada columna de la tabla.*/
	private static final String TEXT_TYPE = " TEXT";
	
	/*Se declara e inicializa una consulta Transact-Sql para la creacin 
	de una tabla formada por tres campos o columnas.*/
	private static final String SQL_CREATE_ENTRIES =
	    "CREATE TABLE " + EstructuraDatos.TABLE_NAME + " (" +
	    EstructuraDatos._ID + " INTEGER PRIMARY KEY AUTOINCREMENT, " +
	    EstructuraDatos.COLUMN_NAME_CLIENTE + TEXT_TYPE + ", " +
	    EstructuraDatos.COLUMN_NAME_TELEFONO + TEXT_TYPE + ", " +
	    EstructuraDatos.COLUMN_NAME_DESCRIPCION + TEXT_TYPE + ")";

	private static final String SQL_DELETE_ENTRIES =
	    "DROP TABLE IF EXISTS " + EstructuraDatos.TABLE_NAME;
	public static final int DATABASE_VERSION = 1;
    public static final String DATABASE_NAME = "Clientes.sqlite";
	public BaseDatos(Context context) {
		super(context, DATABASE_NAME, null, DATABASE_VERSION);
	}

	/*Mtodo que recibe la consulta Transact-SQL para para crear la Tabla.*/
	@Override
	public void onCreate(SQLiteDatabase db) 
	{		
		db.execSQL(SQL_CREATE_ENTRIES);
	}

	/*Mtodo que elimina la tabla y vuelve a invocar al mtodo que la crea.*/
	@Override
	public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
		db.execSQL(SQL_DELETE_ENTRIES);
		onCreate(db);
	}
}
